@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         gnome_prefs_window.c  -  description 
  *                         ------------------------------------
  *   begin                : Mon Oct 15 2003, but based on older code
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : Helpers to create GNOME compliant prefs windows.
  *
  */
@@ -71,7 +71,6 @@ tree_selection_changed_cb (GtkTreeSelection *selection,
   int page = 0;
   gchar *name = NULL;
   GtkTreeIter iter;
-  GtkWidget *label = NULL;
   GtkTreeModel *model = NULL;
   GnomePrefsWindow *gpw = NULL;
 
@@ -167,8 +166,11 @@ gnome_prefs_entry_new (GtkWidget *table,
   g_free (gconf_string);
 
   g_signal_connect_after (G_OBJECT (entry), "focus-out-event",
-			  G_CALLBACK (entry_changed), gconf_key);
-  
+			  G_CALLBACK (entry_focus_changed), gconf_key);
+
+  g_signal_connect_after (G_OBJECT (entry), "activate",
+			  G_CALLBACK (entry_activate_changed), gconf_key);
+
   gconf_client_notify_add (client, gconf_key, entry_changed_nt,
 			   (gpointer) entry, 0, 0);
 
@@ -898,12 +900,12 @@ gnome_prefs_window_subsection_new (GtkWidget *window,
   GtkTreeIter child_iter;
     
   if (!window)
-    return;
+    return NULL;
   
   gpw = (GnomePrefsWindow *) g_object_get_data (G_OBJECT (window), "gpw");
 
   if (!gpw || !section_name)
-    return;
+    return NULL;
 
   container = gtk_vbox_new (FALSE, 4);
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (gpw->sections_tree_view));
