@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         connection.cpp  -  description
  *                         ------------------------------
  *   begin                : Sat Dec 23 2001
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : This file contains connection related functions.
  *
  */
@@ -42,6 +42,7 @@
 #include "endpoint.h"
 #include "gnomemeeting.h"
 #include "misc.h"
+#include "tools.h"
 #include "chat_window.h"
 #include "main_window.h"
 
@@ -72,12 +73,10 @@ GMH323Connection::GMH323Connection (GMH323EndPoint & ep,
   opened_video_channels = 0;
 
   min_jitter = 
-    gconf_client_get_int (gconf_client_get_default (), 
-			  AUDIO_CODECS_KEY "minimum_jitter_buffer", NULL);
+    gconf_get_int (AUDIO_CODECS_KEY "minimum_jitter_buffer");
 
   max_jitter = 
-    gconf_client_get_int (gconf_client_get_default (), 
-			  AUDIO_CODECS_KEY "maximum_jitter_buffer", NULL);
+    gconf_get_int (AUDIO_CODECS_KEY "maximum_jitter_buffer");
   gnomemeeting_threads_leave ();
 
   SetAudioJitterDelay (PMAX (min_jitter, 20), PMIN (max_jitter, 1000));
@@ -166,7 +165,7 @@ GMH323Connection::OnLogicalChannel (H323Channel *channel,
 
   /* Update the GUI and menus wrt opened channels */
   gnomemeeting_threads_enter ();
-  gnomemeeting_log_insert (gw->history_text_view, msg);
+  gnomemeeting_log_insert (msg);
   gnomemeeting_menu_update_sensitivity (is_video, is_video?is_receiving_video:is_receiving_audio, is_video?is_transmitting_video:is_transmitting_audio);
   gnomemeeting_main_window_update_sensitivity (is_video, is_video?is_receiving_video:is_receiving_audio, is_video?is_transmitting_video:is_transmitting_audio);
   if (!is_receiving_video && !is_transmitting_video && !preview)
@@ -184,7 +183,6 @@ GMH323Connection::OpenLogicalChannel (const H323Capability &capability,
 				      H323Channel::Directions dir)
 {
   GmWindow *gw = NULL;
-  gchar *msg = NULL;
   BOOL success = FALSE;
   
   gw = GnomeMeeting::Process ()->GetMainWindow ();
@@ -196,19 +194,13 @@ GMH323Connection::OpenLogicalChannel (const H323Capability &capability,
      will ..." or "Failure opening XXX for reception, will ..." where
      XXX is for example GSM-06.10 */
   if (!success) {
-
-    msg =
-      g_strdup_printf (_("Failure opening %s for %s, will try with next common codec"),
-		       (const char *) capability.GetFormatName (),
-		       (dir == H323Channel::IsTransmitter) ?
-		       _("transmission") : _("reception"));
-
     
     gnomemeeting_threads_enter ();
-    gnomemeeting_log_insert (gw->history_text_view, msg);
+    gnomemeeting_log_insert ((dir == H323Channel::IsTransmitter)
+				? _("Failure opening %s for transmission, will try with next common codec")
+				: _("Failure opening %s for reception, will try with next common codec"),
+				(const char *) capability.GetFormatName ());
     gnomemeeting_threads_leave ();
-
-    g_free (msg);
   }
   
   return success;
@@ -245,7 +237,6 @@ void GMH323Connection::OnUserInputString(const PString & value)
   PString val;
   PString remote = GetRemotePartyName ();
   PINDEX bracket;
-  GConfClient *client = gconf_client_get_default ();
 
   /* The remote party name has to be converted to UTF-8, but not
      the text */
@@ -282,8 +273,7 @@ void GMH323Connection::OnUserInputString(const PString & value)
     gnomemeeting_text_chat_insert (utf8_remote, val, 1);
   
   if (!GTK_WIDGET_VISIBLE (gw->chat_window))
-    gconf_client_set_bool (client, USER_INTERFACE_KEY "main_window/show_chat_window",
-			   true, NULL);
+    gconf_set_bool (USER_INTERFACE_KEY "main_window/show_chat_window", true);
 
   g_free (utf8_remote);
   gnomemeeting_threads_leave ();
@@ -322,7 +312,7 @@ GMH323Connection::HandleCallTransferFailure (const int returnError)
   gnomemeeting_threads_enter ();
   gw = GnomeMeeting::Process ()->GetMainWindow ();
   gnomemeeting_error_dialog (GTK_WINDOW (gm), _("Call transfer failed"), _("The remote user tried to transfer your call to another user, but it failed."));
-  gnomemeeting_log_insert (gw->history_text_view, _("Call transfer failed"));
+  gnomemeeting_log_insert (_("Call transfer failed"));
   gnomemeeting_threads_leave ();
 }
 
