@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         gdkvideoio.cpp  -  description
  *                         ------------------------------
  *   begin                : Sat Feb 17 2001
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : Class to permit to display in GDK Drawing Area or
  *                          SDL.
  *
@@ -44,6 +44,8 @@
 #include "misc.h"
 #include "menu.h"
 
+#include "gconf_widgets_extensions.h"
+
 #include <ptlib/vconvert.h>
 
 #ifdef HAS_SDL
@@ -56,30 +58,49 @@
 
 extern GtkWidget *gm;
 
-int GDKVideoOutputDevice::devices_nbr = 0;
-
 
 /* The Methods */
 GDKVideoOutputDevice::GDKVideoOutputDevice(int idno, GmWindow *w)
 {
+#ifdef HAS_SDL
+  BOOL start_in_fullscreen = FALSE;
+#endif
+  
   gw = w;
 
   /* Used to distinguish between input and output device. */
   device_id = idno; 
 
-  devices_nbr++;
-  
 #ifdef HAS_SDL
   screen = NULL;
   overlay = NULL;
+
+  gnomemeeting_threads_enter ();
+  
+  /* Do we start in fullscreen or not */
+  start_in_fullscreen = 
+    gconf_get_bool (VIDEO_DISPLAY_KEY "start_in_fullscreen");
+  
+  /* Change the zoom value following we have to start in fullscreen
+   * or not */
+  if (!start_in_fullscreen) {
+    
+    if (gconf_get_float (VIDEO_DISPLAY_KEY "zoom_factor") == -1.0)
+      gconf_set_float (VIDEO_DISPLAY_KEY "zoom_factor", 1.00);
+  } 
+  else {
+
+    gconf_set_float (VIDEO_DISPLAY_KEY "zoom_factor", -1.0);
+  }
+
+  gnomemeeting_threads_leave ();
 #endif
 }
 
 
 GDKVideoOutputDevice::~GDKVideoOutputDevice()
 {
-  redraw_mutex.Wait ();
-  redraw_mutex.Signal ();
+  PWaitAndSignal m(redraw_mutex);
 
 #ifdef HAS_SDL
   /* If it is needed, delete the SDL window */
@@ -94,8 +115,6 @@ GDKVideoOutputDevice::~GDKVideoOutputDevice()
   }
 #endif
 
-  devices_nbr--;
-  
   /* Hide the 2 popup windows */
   gnomemeeting_threads_enter ();
   gnomemeeting_window_hide (GTK_WIDGET (gw->local_video_window));
@@ -106,6 +125,8 @@ GDKVideoOutputDevice::~GDKVideoOutputDevice()
 
 BOOL GDKVideoOutputDevice::Redraw ()
 {
+  GMH323EndPoint *ep = NULL;
+  
   GtkWidget *image = NULL;
   GtkWidget *window = NULL;
   GdkPixbuf *src_pic = NULL;
@@ -113,7 +134,6 @@ BOOL GDKVideoOutputDevice::Redraw ()
   GdkPixbuf *tmp = NULL;
   int image_width = 0, image_height = 0;
   PMutex both_mutex;
-  GConfClient *client = NULL;
 
   gboolean unref = true;
 
@@ -121,7 +141,7 @@ BOOL GDKVideoOutputDevice::Redraw ()
   int zoomed_width = GM_QCIF_WIDTH; 
   int zoomed_height = GM_QCIF_HEIGHT;
 
-  int display = 0;
+  int display = LOCAL_VIDEO;
 
   /* Common to the 2 instances of gdkvideoio */
   static GdkPixbuf *local_pic = NULL;
@@ -129,7 +149,6 @@ BOOL GDKVideoOutputDevice::Redraw ()
   static double zoom = 1.0;
 
 #ifdef HAS_SDL
-  static gboolean fullscreen = false;
   static gboolean has_to_fs = false;
   static gboolean has_to_switch_fs = false;
   static gboolean old_fullscreen = false;
@@ -139,54 +158,47 @@ BOOL GDKVideoOutputDevice::Redraw ()
   SDL_Surface *blit_conf = NULL;
 #endif
 
-
+  ep = GnomeMeeting::Process ()->Endpoint ();
+  
   gnomemeeting_threads_enter ();
-  client = gconf_client_get_default ();
 
+  
   /* Take the mutexes before the redraw */
   redraw_mutex.Wait ();
 
 
   /* Updates the zoom value */
-  zoom = 
-    gconf_client_get_float (client, 
-			    VIDEO_DISPLAY_KEY "zoom_factor", 
-			    NULL);
-  if (zoom != 0.5 && zoom != 1 && zoom != 2)
+  zoom = gconf_get_float (VIDEO_DISPLAY_KEY "zoom_factor");
+  
+  if (zoom != 0.5 && zoom != 1 && zoom != 2 && zoom != -1.00)
     zoom = 1.0;
 
-#ifdef HAS_SDL 
-  fullscreen =
-    gconf_client_get_bool (client, 
-			  VIDEO_DISPLAY_KEY "start_in_fullscreen", 0);
-#endif
 
+  /* If we are not in a call, then display the local video. If we
+   * are in a call, then display what GConf tells us, except if
+   * it requests to display both video streams and that there is only
+   * one available 
+   */
+  display = gconf_get_int (VIDEO_DISPLAY_KEY "video_view");
+
+  if (!ep->CanAutoStartTransmitVideo () 
+      || !ep->CanAutoStartReceiveVideo ()) {
+
+    if (device_id == REMOTE)
+      display = REMOTE_VIDEO;
+    else if (device_id == LOCAL)
+      display = LOCAL_VIDEO;
+  }
+
+  if (ep->GetCallingState () != GMH323EndPoint::Connected) 
+    display = LOCAL_VIDEO;
 
-  /* Let's go for the GTK stuff */
   
-  /* What do we display: what gconf tells us except if we are not in 
-     a call, or if it is not a valid choice */
-  if (GnomeMeeting::Process ()->Endpoint ()->GetCallingState () != 2) {
-
-    display = 0;
-  }
-  else {
-
-    display = 
-      gconf_client_get_int (client, 
-			    VIDEO_DISPLAY_KEY "video_view", 
-			    NULL);
-
-    if (devices_nbr <= 1)
-      if (device_id == REMOTE)
-	display = REMOTE_VIDEO;
-      else if (device_id == LOCAL)
-	display = LOCAL_VIDEO;
-  }
-
+  /* Update the display selection in the main and in the video popup menus */
   gtk_radio_menu_select_with_id (gw->main_menu, "local_video", display);
   gtk_radio_menu_select_with_id (gw->video_popup_menu, "local_video", display);
 
+  
   /* Show or hide the different windows if needed */
   if (display == BOTH) { /* display == BOTH */
 
@@ -197,10 +209,10 @@ BOOL GDKVideoOutputDevice::Redraw ()
       logo_displayed = true;
     }
 
-    if (!GTK_WIDGET_VISIBLE (gw->local_video_window))
+    if (device_id == LOCAL && !GTK_WIDGET_VISIBLE (gw->local_video_window))
       gnomemeeting_window_show (GTK_WIDGET (gw->local_video_window));
     
-    if (!GTK_WIDGET_VISIBLE (gw->remote_video_window))
+    if (device_id == REMOTE && !GTK_WIDGET_VISIBLE (gw->remote_video_window))
       gnomemeeting_window_show (GTK_WIDGET (gw->remote_video_window));
 
     if (device_id == REMOTE) {
@@ -238,7 +250,7 @@ BOOL GDKVideoOutputDevice::Redraw ()
 			     &zoomed_height);
       }
 
-      if (!GTK_WIDGET_VISIBLE (gw->local_video_window))
+      if (device_id == LOCAL && !GTK_WIDGET_VISIBLE (gw->local_video_window))
 	gnomemeeting_window_show (GTK_WIDGET (gw->local_video_window));
       
       if (GTK_WIDGET_VISIBLE (gw->remote_video_window))
@@ -261,7 +273,7 @@ BOOL GDKVideoOutputDevice::Redraw ()
 
   /* If we are in fullscreen, but that the option is not to be in
      fullscreen, delete the fullscreen SDL window */
-  if ((screen) && (!fullscreen)) {
+  if (screen && zoom != -1.00) {
     
     SDL_FreeSurface (screen);
     screen = NULL;
@@ -271,24 +283,18 @@ BOOL GDKVideoOutputDevice::Redraw ()
   else
     /* If fullscreen is selected but that we are not in fullscreen, 
        call SDL init */
-    if ((fullscreen) && (!screen))
+    if (zoom == -1.0 && !screen)
       SDL_Init (SDL_INIT_VIDEO);
 
   sdl_mutex.Signal ();
 
 
 
-  if (has_to_fs) {
+  if (zoom == -1.0) {
       
-    zoomed_width = 
-      gconf_client_get_int (client, 
-			    VIDEO_DISPLAY_KEY "fullscreen_width", 
-			    NULL);
-    zoomed_height = 
-      gconf_client_get_int (client, 
-			    VIDEO_DISPLAY_KEY "fullscreen_height", 
-			    NULL);
-    }
+    zoomed_width = gconf_get_int (VIDEO_DISPLAY_KEY "fullscreen_width");
+    zoomed_height = gconf_get_int (VIDEO_DISPLAY_KEY "fullscreen_height");
+  }
 #endif
 
   
@@ -301,7 +307,7 @@ BOOL GDKVideoOutputDevice::Redraw ()
   g_object_unref (tmp);
 
 
-  if (gconf_client_get_bool (client, VIDEO_DISPLAY_KEY "enable_bilinear_filtering", NULL)) 
+  if (gconf_get_bool (VIDEO_DISPLAY_KEY "enable_bilinear_filtering")) 
     interp_type = GDK_INTERP_BILINEAR;
 
 
@@ -325,7 +331,9 @@ BOOL GDKVideoOutputDevice::Redraw ()
   gtk_widget_get_size_request (GTK_WIDGET (gw->video_frame), 
 			       &image_width, &image_height);
 
-  if ( ((image_width != zoomed_width) || (image_height != zoomed_height)) 
+  if ( zoom != -1.0
+       &&
+      ((image_width != zoomed_width) || (image_height != zoomed_height)) 
        &&
       ( ((device_id == LOCAL) && (display == LOCAL_VIDEO)) ||
 	((device_id == REMOTE) && (display == REMOTE_VIDEO)) ||
@@ -343,13 +351,13 @@ BOOL GDKVideoOutputDevice::Redraw ()
   /* Need to go full screen or to close the SDL window ? */
   gnomemeeting_threads_enter ();
   sdl_mutex.Wait ();
-  has_to_fs = fullscreen;
+  has_to_fs = (zoom == -1.0);
 
   /* Need to toggle fullscreen */
-  if (old_fullscreen == !fullscreen) {
+  if (old_fullscreen == !has_to_fs) {
 
     has_to_switch_fs = true;
-    old_fullscreen = fullscreen;
+    old_fullscreen = has_to_fs;
   }
 
   SDL_Event event;
@@ -365,8 +373,8 @@ BOOL GDKVideoOutputDevice::Redraw ()
 	    (event.key.keysym.sym == SDLK_f)) {
 
 	  has_to_fs = !has_to_fs;
-	  fullscreen = has_to_fs;
-	  has_to_switch_fs = true;
+	  gconf_set_float (VIDEO_DISPLAY_KEY "zoom_factor", 1.0);
+          has_to_switch_fs = true;
 	}
       }
 
@@ -387,31 +395,33 @@ BOOL GDKVideoOutputDevice::Redraw ()
 
 
   /* We display what we transmit, or what we receive */
-  if ( (((device_id == 0 && display == 1) ||
-	(device_id == 1 && display == 0)) && (display != 2)) 
-       || ((display == 3) && (device_id == 0)) ) {
-    
-    gnomemeeting_threads_enter ();
-    gtk_image_set_from_pixbuf (GTK_IMAGE (gw->main_video_image), 
- 			       GDK_PIXBUF (zoomed_pic));
-    gnomemeeting_threads_leave ();
-  }
-   
-    
-  if ( (display == BOTH) || 
-       ((display == BOTH_LOCAL) && (device_id == LOCAL)) ) {
-    
-    gnomemeeting_threads_enter ();
-    if (device_id == LOCAL)
-      gtk_image_set_from_pixbuf (GTK_IMAGE (gw->local_video_image), 
-				 GDK_PIXBUF (zoomed_pic));
-    else
-      gtk_image_set_from_pixbuf (GTK_IMAGE (gw->remote_video_image), 
-				 GDK_PIXBUF (zoomed_pic));
+  if (zoom != -1.0) {
 
-    gnomemeeting_threads_leave ();
-  }
+    if ( (((device_id == REMOTE && display == REMOTE_VIDEO) ||
+           (device_id == LOCAL && display == LOCAL_VIDEO)) && (display != BOTH_INCRUSTED)) 
+         || ((display == BOTH_LOCAL) && (device_id == REMOTE)) ) {
 
+      gnomemeeting_threads_enter ();
+      gtk_image_set_from_pixbuf (GTK_IMAGE (gw->main_video_image), 
+                                 GDK_PIXBUF (zoomed_pic));
+      gnomemeeting_threads_leave ();
+    }
+
+
+    if ( (display == BOTH) || 
+         ((display == BOTH_LOCAL) && (device_id == LOCAL)) ) {
+
+      gnomemeeting_threads_enter ();
+      if (device_id == LOCAL)
+        gtk_image_set_from_pixbuf (GTK_IMAGE (gw->local_video_image), 
+                                   GDK_PIXBUF (zoomed_pic));
+      else
+        gtk_image_set_from_pixbuf (GTK_IMAGE (gw->remote_video_image), 
+                                   GDK_PIXBUF (zoomed_pic));
+
+      gnomemeeting_threads_leave ();
+    }
+  }
 
 #ifdef HAS_SDL
   /* Display local in a SDL window, or the selected device in fullscreen */
@@ -472,10 +482,10 @@ BOOL GDKVideoOutputDevice::Redraw ()
 
 
   /* we display both of them */
-  if (display == 2) {
+  if (display == BOTH_INCRUSTED) {
 
     /* What we transmit, in small */
-    if (device_id == 1) {
+    if (device_id == LOCAL) {
 
       both_mutex.Wait ();
       gnomemeeting_threads_enter ();
@@ -495,7 +505,7 @@ BOOL GDKVideoOutputDevice::Redraw ()
     }
 
     /* What we receive, in big */
-    if ((device_id == 0) && (local_pic))  {
+    if ((device_id == REMOTE) && (local_pic))  {
 
       both_mutex.Wait ();
       gnomemeeting_threads_enter ();
