@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         misc.h  -  description
  *                         ----------------------
  *   begin                : Thu Nov 22 2001
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : This file contains miscellaneous functions.
  *   Additional Code      : De Michele Cristiano, Miguel Rodrguez 
  *
@@ -73,18 +73,6 @@ gnomemeeting_button_new (const char *,
 			 GtkWidget *);
 
 
-/* DESCRIPTION  :  /
- * BEHAVIOR     :  Add text (gchar *) with timestamps into the given 
- *                 GtkTextView.
- * PRE          :  The text to add (printf compatible),
- *                 and the text view to add the text into.
- */
-void 
-gnomemeeting_log_insert (GtkWidget *,
-			 const char *,
-			 ...);
-
-
 /* DESCRIPTION  :  /
  * BEHAVIOR     :  Displays the gnomemeeting logo in the drawing area.
  * PRE          :  The GtkImage where to put the logo (pixbuf).
@@ -156,6 +144,15 @@ gdk_window_set_always_on_top (GdkWindow *window,
 			      gboolean enable);
 
 
+
+/* DESCRIPTION  :  / 
+ * BEHAVIOR     :  Returns TRUE if the specified window is present and visible
+ *                 on the current workspace, FALSE otherwise.
+ * PRE          :  Argument is a GtkWindow *.
+ */
+gboolean gnomemeeting_window_is_visible (GtkWidget *);
+        
+
 /* DESCRIPTION  :  This callback is called when a window of gnomemeeting
  *                 (addressbook, prefs, ...) has to be shown.
  * BEHAVIOR     :  Restore its size (if applicable) and position from the GConf
