@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                        toolbar.cpp  -  description
  *                        ---------------------------
  *   begin                : Sat Dec 23 2000
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : This file contains all the functions needed to
  *                          create the toolbar.
  *
@@ -81,13 +81,10 @@ static void url_combo_changed (GtkEditable  *e, gpointer data)
  */
 static void connect_button_clicked (GtkToggleButton *w, gpointer data)
 {
-  if (gtk_toggle_button_get_active (w))
-    if (GnomeMeeting::Process ()->Endpoint ()->GetCallingState () == GMH323EndPoint::Standby) 
-      GnomeMeeting::Process ()->Connect ();
-    else 
-      connect_button_update_pixmap (w, 1);
+  if (gtk_toggle_button_get_active (w))  
+    connect_cb (NULL, NULL);  
   else
-    GnomeMeeting::Process ()->Disconnect ();
+    disconnect_cb (NULL, NULL);
 }
 
 
@@ -99,17 +96,13 @@ static void connect_button_clicked (GtkToggleButton *w, gpointer data)
  */
 static void toolbar_cp_button_changed (GtkWidget *w, gpointer data)
 {
-  GConfClient *client = gconf_client_get_default ();
-
-  if (gconf_client_get_int (client, (gchar *) data, 0) 
+  if (gconf_get_int ((gchar *) data) 
       == GM_MAIN_NOTEBOOK_HIDDEN) { 
     
-    gconf_client_set_int (client, (gchar *) data, 0, NULL);
+    gconf_set_int ((gchar *) data, 0);
   } 
-  else {    
-    
-    gconf_client_set_int (client, (gchar *) data, GM_MAIN_NOTEBOOK_HIDDEN, 
-			  NULL);
+  else {   
+    gconf_set_int ((gchar *) data, GM_MAIN_NOTEBOOK_HIDDEN);
   }
 }
 
@@ -122,11 +115,9 @@ static void toolbar_cp_button_changed (GtkWidget *w, gpointer data)
  */
 static void toolbar_button_changed (GtkWidget *widget, gpointer data)
 {
-  GConfClient *client = gconf_client_get_default ();
-  
-  bool shown = gconf_client_get_bool (client, (gchar *) data, NULL);
+  bool shown = gconf_get_bool ((gchar *) data);
 
-  gconf_client_set_bool (client, (gchar *) data, !shown, NULL);
+  gconf_set_bool ((gchar *) data, !shown);
 }
 
 
@@ -174,7 +165,7 @@ gnomemeeting_init_main_toolbar ()
   /* The connect button */
   gw->connect_button = gtk_toggle_button_new ();
   gtk_tooltips_set_tip (gw->tips, GTK_WIDGET (gw->connect_button), 
-			_("Enter an URL to call on the left, and click on this button to connect to the given URL."), NULL);
+			_("Enter an URL to call on the left, and click on this button to connect to the given URL"), NULL);
   
   image = gtk_image_new_from_stock (GM_STOCK_DISCONNECT, 
                                     GTK_ICON_SIZE_LARGE_TOOLBAR);
@@ -220,7 +211,7 @@ GtkWidget *gnomemeeting_init_left_toolbar (void)
   gtk_widget_show (image);
   gtk_toolbar_append_item (GTK_TOOLBAR (left_toolbar),
 			   NULL,
-			   _("Open text chat."), 
+			   _("Open text chat"), 
 			   NULL,
 			   image,
 			   GTK_SIGNAL_FUNC (toolbar_button_changed),
@@ -267,7 +258,7 @@ GtkWidget *gnomemeeting_init_left_toolbar (void)
 		    (gpointer) VIDEO_DEVICES_KEY "enable_preview");
 
   gtk_tooltips_set_tip (gw->tips, gw->preview_button,
-			_("Display images from your camera device."),
+			_("Display images from your camera device"),
 			NULL);
 
   gtk_toolbar_append_widget (GTK_TOOLBAR (left_toolbar), 
