@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                          urlhandler.cpp  -  description
  *                          ------------------------------
  *   begin                : Sat Jun 8 2002
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : Multithreaded class to call a given URL or to
  *                          answer a call.
  *
@@ -75,7 +75,7 @@ TransferTimeOut (gpointer data)
 
     gw = GnomeMeeting::Process ()->GetMainWindow ();
     gnomemeeting_error_dialog (GTK_WINDOW (gm), _("Call transfer failed"), _("The call transfer failed, the user was either unreachable, or simply busy when he received the call transfer request."));
-    gnomemeeting_log_insert (gw->history_text_view, _("Call transfer failed"));
+    gnomemeeting_log_insert (_("Call transfer failed"));
   }
   gdk_threads_leave ();
 
@@ -285,11 +285,9 @@ void GMURLHandler::Main ()
 
     if (url.IsEmpty ()) {
 
-      msg = g_strdup_printf (_("No contact with speed dial %s# found, will call number %s instead"), (const char *) old_url.GetValidURL (), (const char *) (GMURL ().GetDefaultURL () + old_url.GetValidURL ()));
       gnomemeeting_threads_enter ();
-      gnomemeeting_log_insert (gw->history_text_view, msg);
+      gnomemeeting_log_insert (_("No contact with speed dial %s# found, will call number %s instead"), (const char *) old_url.GetValidURL (), (const char *) (GMURL ().GetDefaultURL () + old_url.GetValidURL ()));
       gnomemeeting_threads_leave ();
-      g_free (msg);
       
       url = GMURL (GMURL ().GetDefaultURL () + old_url.GetValidURL ());
     }
@@ -329,19 +327,19 @@ void GMURLHandler::Main ()
       else
 	msg = g_strdup_printf (_("Transferring call to %s"), 
 			       (const char *) call_address);
-      gnomemeeting_log_insert (gw->history_text_view, msg);
+      gnomemeeting_log_insert (msg);
       gnomemeeting_statusbar_push (gw->statusbar, msg);
     }
     g_free (msg);
 
     gnomemeeting_threads_leave ();
   
+    if (use_gateway && !gateway.IsEmpty ()) 	
+      call_address = call_address + "@" + gateway;
+
     /* Connect to the URL */
     if (!transfer_call) {
 
-      if (use_gateway && !gateway.IsEmpty ()) 	
-	call_address = call_address + "@" + gateway;
-      cout << call_address << endl << flush;
       con = 
 	endpoint->MakeCallLocked (call_address, current_call_token);
     }
